@@ -12,7 +12,8 @@ from traitlets import Bool, Unicode
 from ._version import __version__
 from .extension import load_jupyter_server_extension
 from .commands import (
-    build, clean, get_app_dir, get_user_settings_dir, app_version
+    build, clean, get_app_dir, get_user_settings_dir, get_app_version,
+    get_workspaces_dir, get_app_dir
 )
 
 
@@ -21,8 +22,14 @@ build_aliases['app-dir'] = 'LabBuildApp.app_dir'
 build_aliases['name'] = 'LabBuildApp.name'
 build_aliases['version'] = 'LabBuildApp.version'
 
+build_flags = dict(flags)
+build_flags['dev'] = (
+    {'LabBuildApp': {'dev_build': True}},
+    "Build in Development mode"
+)
 
 version = __version__
+app_version = get_app_version()
 if version != app_version:
     version = '%s (dev), %s (app)' % (__version__, app_version)
 
@@ -37,6 +44,7 @@ class LabBuildApp(JupyterApp):
     directory, where it is used to serve the application.
     """
     aliases = build_aliases
+    flags = build_flags
 
     app_dir = Unicode('', config=True,
         help="The app directory to build in")
@@ -47,8 +55,16 @@ class LabBuildApp(JupyterApp):
     version = Unicode('', config=True,
         help="The version of the built application")
 
+    dev_build = Bool(True, config=True,
+        help="Whether to build in dev mode (defaults to dev mode)")
+
     def start(self):
-        build(self.app_dir, self.name, self.version)
+        command = 'build:prod' if not self.dev_build else 'build'
+        app_dir = self.app_dir or get_app_dir()
+        self.log.info('JupyterLab %s', version)
+        self.log.info('Building in %s', app_dir)
+        build(app_dir=app_dir, name=self.name, version=self.version,
+              command=command, logger=self.log)
 
 
 clean_aliases = dict(base_aliases)
@@ -81,11 +97,15 @@ class LabPathApp(JupyterApp):
     The user settings path can be configured using the JUPYTERLAB_SETTINGS_DIR
         environment variable or it will fall back to
         `/lab/user-settings` in the default Jupyter configuration directory.
+    The workspaces path can be configured using the JUPYTERLAB_WORKSPACES_DIR
+        environment variable or it will fall back to
+        '/lab/workspaces' in the default Jupyter configuration directory.
     """
 
     def start(self):
         print('Application directory:   %s' % get_app_dir())
         print('User Settings directory: %s' % get_user_settings_dir())
+        print('Workspaces directory: %s' % get_workspaces_dir())
 
 
 lab_aliases = dict(aliases)
@@ -97,7 +117,7 @@ lab_flags['core-mode'] = (
     "Start the app in core mode."
 )
 lab_flags['dev-mode'] = (
-    {'LabApp': {'core_mode': True}},
+    {'LabApp': {'dev_mode': True}},
     "Start the app in dev mode for running from source."
 )
 lab_flags['watch'] = (
@@ -121,9 +141,9 @@ class LabApp(NotebookApp):
       assets contained in the installed `jupyterlab` Python package. In core mode, no
       extensions are enabled. This is the default in a stable JupyterLab release if you
       have no extensions installed.
-    * Dev mode (`--dev-mode`): like core mode, but when the `jupyterlab` Python package
-      is installed from source and installed using `pip install -e .`. In this case
-      JupyterLab will show a red stripe at the top of the page.
+    * Dev mode (`--dev-mode`): uses the unpublished local JavaScript packages in the
+      `dev_mode` folder.  In this case JupyterLab will show a red stripe at the top of
+      the page.  It can only be used if JupyterLab is installed as `pip install -e .`.
     * App mode: JupyterLab allows multiple JupyterLab "applications" to be
       created by the user with different combinations of extensions. The `--app-dir` can
       be used to set a directory for different applications. The default application
@@ -151,9 +171,15 @@ class LabApp(NotebookApp):
     default_url = Unicode('/lab', config=True,
         help="The default URL to redirect to from `/`")
 
-    app_dir = Unicode('', config=True,
+    app_dir = Unicode(get_app_dir(), config=True,
         help="The app directory to launch JupyterLab from.")
 
+    user_settings_dir = Unicode(get_user_settings_dir(), config=True,
+        help="The directory for user settings.")
+
+    workspaces_dir = Unicode(get_workspaces_dir(), config=True,
+        help="The directory for workspaces")
+
     core_mode = Bool(False, config=True,
         help="""Whether to start the app in core mode. In this mode, JupyterLab
         will run using the JavaScript assets that are within the installed
@@ -162,6 +188,13 @@ class LabApp(NotebookApp):
         itself is installed in development mode (`pip install -e .`).
         """)
 
+    dev_mode = Bool(False, config=True,
+        help="""Whether to start the app in dev mode. Uses the unpublished local
+        JavaScript packages in the `dev_mode` folder.  In this case JupyterLab will
+        show a red stripe at the top of the page.  It can only be used if JupyterLab
+        is installed as `pip install -e .`.
+        """)
+
     watch = Bool(False, config=True,
         help="Whether to serve the app in watch mode")
 
